//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Device/Unit/AxisNames.cpp
//! @brief     Implements functions in namespace AxisNames.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "Device/Unit/AxisNames.h"
#include <map>

namespace AxisNames {

// For spherical detectors in GISAS simulations
BA_DEVICE_API_ const std::map<Axes::Units, std::string> sphericalAxis0 = {
        { Axes::Units::NBINS, "X [nbins]" },
        { Axes::Units::RADIANS, "phi_f [rad]" },
        { Axes::Units::DEGREES, "phi_f [deg]" },
        { Axes::Units::QSPACE, "Qy [1/nm]" },
        { Axes::Units::QXQY, "Qx [1/nm]" } };
BA_DEVICE_API_ const std::map<Axes::Units, std::string> sphericalAxis1 = {
        { Axes::Units::NBINS, "Y [nbins]" },
        { Axes::Units::RADIANS, "alpha_f [rad]" },
        { Axes::Units::DEGREES, "alpha_f [deg]" },
        { Axes::Units::QSPACE, "Qz [1/nm]" },
        { Axes::Units::QXQY, "Qy [1/nm]" } };

// For rectangular detectors in GISAS simulations
BA_DEVICE_API_ const std::map<Axes::Units, std::string> rectangularAxis0 = {
        { Axes::Units::NBINS, "X [nbins]" },
        { Axes::Units::RADIANS, "phi_f [rad]" },
        { Axes::Units::DEGREES, "phi_f [deg]" },
        { Axes::Units::MM, "X [mm]" },
        { Axes::Units::QSPACE, "Qy [1/nm]" },
        { Axes::Units::QXQY, "Qx [1/nm]" } };
BA_DEVICE_API_ const std::map<Axes::Units, std::string> rectangularAxis1 = {
        { Axes::Units::NBINS, "Y [nbins]" },
        { Axes::Units::RADIANS, "alpha_f [rad]" },
        { Axes::Units::DEGREES, "alpha_f [deg]" },
        { Axes::Units::MM, "Y [mm]" },
        { Axes::Units::QSPACE, "Qz [1/nm]" },
        { Axes::Units::QXQY, "Qy [1/nm]" } };

// For off-specular simulations (both spherical and rectangular detectors)
// Currently 'mm' is not supported for the y-axis
BA_DEVICE_API_ const std::map<Axes::Units, std::string> offSpecularAxis0 = {
    { Axes::Units::NBINS, "X [nbins]" },
    { Axes::Units::RADIANS, "alpha_i [rad]" },
    { Axes::Units::DEGREES, "alpha_i [deg]" }};
BA_DEVICE_API_ const std::map<Axes::Units, std::string> offSpecularAxis1 = {
    { Axes::Units::NBINS, "Y [nbins]" },
    { Axes::Units::RADIANS, "alpha_f [rad]" },
    { Axes::Units::DEGREES, "alpha_f [deg]" }};

BA_DEVICE_API_ const std::map<Axes::Units, std::string> specAxis = {
    { Axes::Units::NBINS, "X [nbins]" },
    { Axes::Units::RADIANS, "alpha_i [rad]" },
    { Axes::Units::DEGREES, "alpha_i [deg]" },
    { Axes::Units::QSPACE, "Q [1/nm]" },
    { Axes::Units::RQ4, "Q [1/nm]" } };

BA_DEVICE_API_ const std::map<Axes::Units, std::string> specAxisQ = {
    { Axes::Units::NBINS, "X [nbins]" },
    { Axes::Units::QSPACE, "Q [1/nm]" },
    { Axes::Units::RQ4, "Q [1/nm]" } };

// corner case: axis corresponding to the position
// across sample is accepts only bins and nanometers,
// but the units specified in dedicated unit
// converter correspond to inclination angular axis.
// For this reason depth axis map returns always
// nanometers except for bins.

BA_DEVICE_API_ const std::map<Axes::Units, std::string> sampleDepthAxis = {
    { Axes::Units::NBINS, "Y [nbins]" },
    { Axes::Units::RADIANS, "Position [nm]" },
    { Axes::Units::DEGREES, "Position [nm]" },
    { Axes::Units::QSPACE, "Position [nm]" } };

} // namespace AxisNames
